@@ -1,13 +1,13 @@
 import os
 from django.db import models
-from ..snowflake import SnowflakeGenerator
+from dektools.snowflake import SnowflakeGenerator
 
 
 class ImageField(models.ImageField):
     def __init__(self, *args, **kwargs):
-        self.snowflake_generator = SnowflakeGenerator.new_instance()
+        self.snowflake_generator = SnowflakeGenerator()
         super().__init__(*args, **kwargs)
 
     def generate_filename(self, instance, filename):
-        filename = str(self.snowflake_generator.get_next_id()) + os.path.splitext(filename)[-1]
+        filename = str(self.snowflake_generator.new_id()) + os.path.splitext(filename)[-1]
         return super().generate_filename(instance, filename)
