@@ -3,7 +3,7 @@ from django.utils.translation import ugettext_lazy as _
 from ..snowflake import SnowflakeGenerator
 
 
-class SnowflakeField(models.IntegerField):
+class SnowflakeField(models.PositiveBigIntegerField):
     description = _("雪花ID")
     MAX_VALUE = SnowflakeGenerator.MAX_VALUE
 
