@@ -3,9 +3,9 @@ from ..base import CommandBasic
 
 
 class Command(CommandBasic):
-    just_for_debug_mode = True
-
     def handle(self):
+        if self.just_for_debug_mode():
+            return
         call_command('reset_db', interactive=False)
         call_command('djdelmigrations')
         call_command('makemigrations')
